gchecky.controller.DataError

Package gchecky :: Module controller :: Class DataError |
[hide private]
[frames] | no frames]

# Class DataError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                        GcheckyError --+
                                       |
                                      DataError

An exception of this class occures whenever there is error in converting python data to/from xml.

Instance Methods | [hide private]
Inherited from `GcheckyError`: `__init__`, `__repr__`, `__str__`, `__unicode__` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`